@@ -14,6 +14,8 @@ from pyramid.interfaces import IDebugLogger
 from pyramid.security import Authenticated
 from pyramid.security import Everyone
 
+from pyramid.util import strings_differ
+
 VALID_TOKEN = re.compile(r"^[A-Za-z][A-Za-z0-9+_-]*$")
 
 class CallbackAuthenticationPolicy(object):
@@ -486,7 +488,9 @@ def parse_ticket(secret, ticket, ip):
     expected = calculate_digest(ip, timestamp, secret,
                                 userid, tokens, user_data)
 
-    if expected != digest:
+    # Avoid timing attacks (see
+    # http://seb.dbzteam.org/crypto/python-oauth-timing-hmac.pdf)
+    if strings_differ(expected, digest):
         raise BadTicket('Digest signature is not correct',
                         expected=(expected, digest))
 
@@ -723,7 +727,8 @@ class AuthTktCookieHelper(object):
             encoding, encoder = encoding_data
             userid = encoder(userid)
             user_data = 'userid_type:%s' % encoding
-        
+
+        new_tokens = []
         for token in tokens:
             if isinstance(token, unicode):
                 try:
@@ -732,6 +737,8 @@ class AuthTktCookieHelper(object):
                     pass
             if not (isinstance(token, str) and VALID_TOKEN.match(token)):
                 raise ValueError("Invalid token %r" % (token,))
+            new_tokens.append(token)
+        tokens = tuple(new_tokens)
 
         if hasattr(request, '_authtkt_reissued'):
             request._authtkt_reissue_revoked = True
