@@ -128,9 +128,14 @@ class DeprecatedRequestMethodsMixin(object):
     response_headerlist = property(_response_headerlist_get,
                                    _response_headerlist_set,
                                    _response_headerlist_del)
-    response_headerlist = deprecated(
-        response_headerlist,
-        rr_dep % ('headerlist', 'headerlist'))
+
+    hl_dep = ('Accessing and setting "request.response_headerlist" is '
+              'deprecated as of Pyramid 1.1; access the headerlist via '
+              '"request.response.headerlist" and extend headers via '
+              '"request.response.headerlist.extend(alist)" instead of '
+              '"request.response_headerlist = alist"')
+
+    response_headerlist = deprecated(response_headerlist, hl_dep)
 
     # response_status
     def _response_status_get(self):
@@ -360,7 +365,7 @@ class Request(BaseRequest, DeprecatedRequestMethodsMixin, URLMethodsMixin,
 
     @property
     def json_body(self):
-        return json.loads(self.body, encoding=self.charset)
+        return json.loads(self.body.decode(self.charset))
 
 def route_request_iface(name, bases=()):
     # zope.interface treats the __name__ as the __doc__ and changes __name__
