@@ -14,6 +14,7 @@ import os
 from zope.interface import implements
 
 from pyramid.interfaces import ISession
+from pyramid.util import strings_differ
 
 def manage_accessed(wrapped):
     """ Decorator which causes a cookie to be set when a wrapped
@@ -261,17 +262,10 @@ def signed_deserialize(serialized, secret, hmac=hmac):
 
     sig = hmac.new(secret, pickled, sha1).hexdigest()
 
-    if len(sig) != len(input_sig):
-        raise ValueError('Wrong signature length')
-
     # Avoid timing attacks (see
     # http://seb.dbzteam.org/crypto/python-oauth-timing-hmac.pdf)
-    invalid_bits = 0
-    for a, b in zip(sig, input_sig):
-        invalid_bits += a != b
-
-    if invalid_bits:
-        raise ValueError('Invalid bits in signature')
+    if strings_differ(sig, input_sig):
+        raise ValueError('Invalid signature')
 
     return pickle.loads(pickled)
 
