@@ -293,7 +293,7 @@ class TestCompileRoute(unittest.TestCase):
     def test_url_decode_error(self):
         from pyramid.exceptions import URLDecodeError
         matcher, generator = self._callFUT('/:foo')
-        self.assertRaises(URLDecodeError, matcher, '/%FF%FE%8B%00')
+        self.assertRaises(URLDecodeError, matcher, '/\xff\xfe\x8b\x00')
     
     def test_custom_regex(self):
         matcher, generator = self._callFUT('foo/{baz}/biz/{buz:[^/\.]+}.{bar}')
@@ -363,10 +363,10 @@ class TestCompileRouteFunctional(unittest.TestCase):
         self.matches('zzz/{x}*traverse', '/zzz/abc/def/g',
                      {'x':'abc', 'traverse':('def', 'g')})
         self.matches('*traverse', '/zzz/abc', {'traverse':('zzz', 'abc')})
-        self.matches('*traverse', '/zzz/%20abc', {'traverse':('zzz', ' abc')})
-        self.matches('{x}', '/La%20Pe%C3%B1a', {'x':u'La Pe\xf1a'})
-        self.matches('*traverse', '/La%20Pe%C3%B1a/x',
-                     {'traverse':(u'La Pe\xf1a', 'x')})
+        self.matches('*traverse', '/zzz/%20abc', {'traverse':('zzz', '%20abc')})
+        self.matches('{x}', '/La Pe\xc3\xb1a', {'x': u'La Pe\xf1a'})
+        self.matches('*traverse', '/La Pe\xc3\xb1a/x',
+                     {'traverse': (u'La Pe\xf1a', u'x')})
         self.matches('/foo/{id}.html', '/foo/bar.html', {'id':'bar'})
         self.matches('/{num:[0-9]+}/*traverse', '/555/abc/def',
                      {'num':'555', 'traverse':('abc', 'def')})
@@ -386,10 +386,10 @@ class TestCompileRouteFunctional(unittest.TestCase):
         self.matches('zzz/:x*traverse', '/zzz/abc/def/g',
                      {'x':'abc', 'traverse':('def', 'g')})
         self.matches('*traverse', '/zzz/abc', {'traverse':('zzz', 'abc')})
-        self.matches('*traverse', '/zzz/%20abc', {'traverse':('zzz', ' abc')})
-        self.matches(':x', '/La%20Pe%C3%B1a', {'x':u'La Pe\xf1a'})
-        self.matches('*traverse', '/La%20Pe%C3%B1a/x',
-                     {'traverse':(u'La Pe\xf1a', 'x')})
+        self.matches('*traverse', '/zzz/%20abc', {'traverse':('zzz', '%20abc')})
+        self.matches(':x', '/La Pe\xc3\xb1a', {'x': u'La Pe\xf1a'})
+        self.matches('*traverse', '/La Pe\xc3\xb1a/x',
+                     {'traverse': (u'La Pe\xf1a', u'x')})
         self.matches('/foo/:id.html', '/foo/bar.html', {'id':'bar'})
         self.matches('/foo/:id_html', '/foo/bar_html', {'id_html':'bar_html'})
         self.matches('zzz/:_', '/zzz/abc', {'_':'abc'})
